// Alert
import type { AlertData } from '@/types';
import { defineStore } from 'pinia'

export const useAlertStore = defineStore('alert', {
  state: () => ({
    alerts: [] as Array<AlertData>,
  }),
  actions: {
    addAlert(message: string, type: string, timeout: number = 0) {
        // If more than 10 alerts, remove oldest
        if (this.alerts.length > 10) {
            this.alerts.shift();
        }

        // Define alert and assign unique ID
        const alert: AlertData = { message, type, timeout, id: Date.now(), timeoutId: null}
        this.alerts.push(alert);

        // Register timeout for alert
        if (timeout > 0) {
            const timeoutId = setTimeout(() => {
                this.removeSpecific(alert.id);
            }, timeout);
            alert.timeoutId = timeoutId;
        }
    },
    success(message: string, timeout = 0) {
        // add green alert (success)
        this.addAlert(message, 'alert-success', timeout);
    },
    error(message: string, timeout = 0) {
        // add red alert (error)
        this.addAlert(message, 'alert-danger', timeout);
    },
    removeOldest() {
        const oldestAlert = this.alerts.shift();
        // Remove timeout for this alert (avoid errors)
        if (oldestAlert && oldestAlert.timeoutId) {
            clearTimeout(oldestAlert.timeoutId);
        }
    },
    removeSpecific(alertId: number) {
        // Find alert by index
        const index = this.alerts.findIndex((alert) => alert.id === alertId);
        if (index !== -1) {
            const alert = this.alerts[index];
            this.alerts.splice(index, 1);

            // Remove timeout for this alert (avoid errors)
            if (alert.timeoutId) {
                clearTimeout(alert.timeoutId);
            }
        }
    },
    clear() {
        for (const alert of this.alerts) {
            if (alert.timeoutId) {
                clearTimeout(alert.timeoutId)
            }
        }
        this.alerts = [];
    }
  }
})
